@@ -31,6 +31,11 @@ from . import config
 from napari_workflows import Workflow, WorkflowManager
 from napari_workflows._io_yaml_v1 import load_workflow
 
+#Enable Logging
+import logging
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
 
 def _napari_lattice_widget_wrapper():
     #split widget type enables a resizable widget
@@ -47,7 +52,7 @@ def _napari_lattice_widget_wrapper():
             
             main_heading = widgets.Label(value="<h3>Napari Lattice: Visualization & Analysis</h3>")
             heading1 = widgets.Label(value="Drag and drop an image file onto napari.\nOnce image has opened, initialize the\nplugin by clicking the button below.\nEnsure the image layer and voxel sizes are accurate in the prompt.\n If everything initalises properly, the button turns green.")
-            @set_design(background_color="magenta", font_family="Consolas",visible=True,text="Initialize Plugin", max_height=75, font_size = 13) 
+            @set_design(background_color="magenta", font_family="Consolas",visible=True,text="Initialize Plugin", max_height=75, font_size = 13)
             @set_options(pixel_size_dx={"widget_type": "FloatSpinBox", "value":0.1449922,"step": 0.000000001},
                          pixel_size_dy={"widget_type": "FloatSpinBox", "value":0.1449922, "step": 0.000000001},
                          pixel_size_dz={"widget_type": "FloatSpinBox", "value":0.3, "step": 0.000000001},
@@ -64,7 +69,7 @@ def _napari_lattice_widget_wrapper():
                                       merge_all_channel_layers:bool=False, 
                                       skew_dir: str="Y"):
                 
-                print("Using existing image layer")
+                logger.info(f"Using existing image layer")
                 skew_dir = str.upper(skew_dir)
                 assert skew_dir in ('Y', 'X'), "Skew direction not recognised. Enter either Y or X"
                 if skew_dir == "X":
@@ -117,9 +122,9 @@ def _napari_lattice_widget_wrapper():
                 
 
                 
-                print("Pixel size (ZYX): ",(LLSZWidget.LlszMenu.lattice.dz,LLSZWidget.LlszMenu.lattice.dy,LLSZWidget.LlszMenu.lattice.dx))
-                print("Dimensions of image layer (ZYX): ",list(LLSZWidget.LlszMenu.lattice.data.shape[-3:]))
-                print("Dimensions of deskewed image (ZYX): ",LLSZWidget.LlszMenu.lattice.deskew_vol_shape)
+                logger.info(f"Pixel size (ZYX): {LLSZWidget.LlszMenu.lattice.dz,LLSZWidget.LlszMenu.lattice.dy,LLSZWidget.LlszMenu.lattice.dx}")
+                logger.info(f"Dimensions of image layer (ZYX): {list(LLSZWidget.LlszMenu.lattice.data.shape[-3:])}")
+                logger.info(f"Dimensions of deskewed image (ZYX): {LLSZWidget.LlszMenu.lattice.deskew_vol_shape}")
               
                 #Add dimension labels
                 #if channel, and not time
@@ -139,7 +144,8 @@ def _napari_lattice_widget_wrapper():
                 elif LLSZWidget.LlszMenu.lattice.channels==1 and  LLSZWidget.LlszMenu.lattice.time>1:
                     self.parent_viewer.dims.axis_labels = list(('Time',"Z","Y","X"))
 
-                print("Initialised")
+                logger.info(f"Initialised")
+                
                 self["Choose_Image_Layer"].background_color = "green"
                 self["Choose_Image_Layer"].text = "Plugin Initialised"
                 
@@ -156,9 +162,9 @@ def _napari_lattice_widget_wrapper():
                 try:
                     LLSZWidget.LlszMenu.lattice.set_angle(self.angle)
                     LLSZWidget.LlszMenu.lattice.angle_value = self.angle
-                    print("Angle is set to: ", LLSZWidget.LlszMenu.lattice.angle)
+                    logger.info(f"Angle is set to: {LLSZWidget.LlszMenu.lattice.angle}")
                 except AttributeError:
-                    print("Choose image layer first before setting angles")
+                    logger.error(f"Choose image layer first before setting angles")
                 #print(LLSZWidget.LlszMenu.lattice.angle)
                 #print(LLSZWidget.LlszMenu.lattice.angle_value)
                 return
@@ -170,7 +176,7 @@ def _napari_lattice_widget_wrapper():
                 Args:
                     use_GPU (bool, optional): Defaults to True.
                 """
-                print("Use GPU set to, ", use_GPU)
+                logger.info("Use GPU set to, ", use_GPU)
                 LLSZWidget.LlszMenu.dask = not use_GPU
                 return
 
@@ -180,10 +186,10 @@ def _napari_lattice_widget_wrapper():
             @deconvolution.connect
             def _set_decon(self):
                 if self.deconvolution:
-                    print("Deconvolution Activated")
+                    logger.info("Deconvolution Activated")
                     LLSZWidget.LlszMenu.deconvolution.value = True
                 else:
-                    print("Deconvolution Disabled")
+                    logger.info("Deconvolution Disabled")
                     LLSZWidget.LlszMenu.deconvolution.value  = False
                 return
             
@@ -288,7 +294,7 @@ def _napari_lattice_widget_wrapper():
                 @magicclass(name="Cropping Preview",widget_type="scrollable")
                 class Preview_Crop_Menu:
                     
-                    @set_design(font_size=10,text="Click to activate Cropping Preview",background_color="magenta")
+                    @set_design(font_size=10,text="Click to activate Cropping Layer",background_color="magenta")
                     @click(enables =["Import_ImageJ_ROI","Crop_Preview"])
                     def activate_cropping(self):
                         LLSZWidget.WidgetContainer.CropWidget.Preview_Crop_Menu.shapes_layer = self.parent_viewer.add_shapes(shape_type='polygon', edge_width=1, edge_color='white',
@@ -302,7 +308,7 @@ def _napari_lattice_widget_wrapper():
                     heading2 = widgets.Label(value="You can either import ImageJ ROI (.zip) files or manually define ROIs using the shape layer")
                     @click(enabled =False)
                     def Import_ImageJ_ROI(self, path: Path = Path(history.get_open_history()[0])):
-                        print("Opening", path)
+                        logger.info(f"Opening{path}")
                         roi_list = read_imagej_roi(path)
                         #convert to canvas coordinates
                         roi_list = (np.array(roi_list)*LLSZWidget.LlszMenu.lattice.dy).tolist()
@@ -328,7 +334,7 @@ def _napari_lattice_widget_wrapper():
                             assert time < LLSZWidget.LlszMenu.lattice.time, "Time is out of range"
                             assert channel < LLSZWidget.LlszMenu.lattice.channels, "Channel is out of range"
                             
-                            print("Using channel ", channel," and time", time)
+                            logger.info(f"Using channel {channel} and time {time}")
                             
                             vol = LLSZWidget.LlszMenu.lattice.data
                             vol_zyx= vol[time,channel,...]
@@ -353,12 +359,12 @@ def _napari_lattice_widget_wrapper():
                             #As the original image is scaled, the coordinates are in microns, so we need to convert
                             #roi from micron to canvas/world coordinates
                             roi_choice = [x/LLSZWidget.LlszMenu.lattice.dy for x in roi_choice]
-                            print("Previewing ROI ", roi_idx)
+                            logger.info(f"Previewing ROI {roi_idx}")
                             
                             #crop 
                             if LLSZWidget.LlszMenu.deconvolution.value:
-                                print(f"Deskewing for Time:{time} and Channel: {channel} with deconvolution")
-                                psf = LLSZWidget.LlszMenu.lattice.psf[channel]
+                                logger.info(f"Deskewing for Time:{time} and Channel: {channel} with deconvolution")
+                                #psf = LLSZWidget.LlszMenu.lattice.psf[channel]
                                 if LLSZWidget.LlszMenu.lattice.decon_processing == "cuda_gpu":
                                     crop_roi_vol_desk = crop_volume_deskew(original_volume = vol_zyx,
                                                                                 deskewed_volume=deskewed_volume, 
@@ -410,15 +416,16 @@ def _napari_lattice_widget_wrapper():
                 
                 
                     @magicclass(name="Crop and Save Data")
+
                     class CropSaveData:
                         @magicgui(header=dict(widget_type="Label", label="<h3>Crop and Save Data</h3>"),
                                   time_start=dict(label="Time Start:"),
                                   time_end=dict(label="Time End:", value=1),
                                   ch_start=dict(label="Channel Start:"),
                                   ch_end=dict(label="Channel End:", value=1),
-                                  save_as_type={"label":"Save as filetype:","choices":["tif","h5"]},
+                                  save_as_type={"label":"Save as filetype:","choices":["h5","tif"]},
                                   save_path=dict(mode='d', label="Directory to save "))
-
+                        
                         def Crop_Save(self,
                                         header,
                                         time_start: int, 
@@ -430,7 +437,7 @@ def _napari_lattice_widget_wrapper():
                                         save_path: Path = Path(history.get_save_history()[0])):
 
                             if not roi_layer_list:
-                                print("No coordinates found or cropping. Initialise shapes layer and draw ROIs.")
+                                logger.error("No coordinates found or cropping. Initialise shapes layer and draw ROIs.")
                             else:
                                 assert LLSZWidget.LlszMenu.open_file, "Image not initialised"
                                 
@@ -449,14 +456,14 @@ def _napari_lattice_widget_wrapper():
                                 z_start = 0
                                 z_end = deskewed_shape[0]
                                 
-                                print("Cropping and saving files...")           
+                                logger.info("Cropping and saving files...")           
 
                                 #necessary when scale is used for napari.viewer.add_image operations
                                 roi_layer_list = [x/LLSZWidget.LlszMenu.lattice.dy for x in roi_layer_list]
 
                                 for idx, roi_layer in enumerate(tqdm(roi_layer_list, desc="ROI:", position=0)):
                                     #pass arguments for save tiff, callable and function arguments
-                                    print("Processing ROI ",idx)
+                                    logger.info("Processing ROI ",idx)
                                     #pass parameters for the crop_volume_deskew function
 
                                     save_img(vol = img_data,
@@ -485,7 +492,7 @@ def _napari_lattice_widget_wrapper():
                                         )
 
 
-                                print("Cropping and Saving Complete -> ", save_path)
+                                logger.info(f"Cropping and Saving Complete -> {save_path}")
                                 return        
 
             @magicclass(name="Workflow",widget_type="scrollable")
@@ -527,7 +534,7 @@ def _napari_lattice_widget_wrapper():
                             #installs the workflow to napari
                             user_workflow = WorkflowManager.install(self.parent_viewer).workflow
                             parent_dir = workflow_path.resolve().parents[0].__str__()+os.sep
-                            print("Workflow loaded from napari")
+                            logger.info("Workflow loaded from napari")
                         else:
 
                             try:
@@ -538,17 +545,17 @@ def _napari_lattice_widget_wrapper():
                                 sys.path.append(parent_dir)
                                 custom_py_files = get_all_py_files(parent_dir)
                                 if len(custom_py_files)==0: 
-                                    print(f"No custom modules imported. If you'd like to use a cusotm module, place a *.py file in same folder as the workflow file {parent_dir}")
+                                    logger.error(f"No custom modules imported. If you'd like to use a cusotm module, place a *.py file in same folder as the workflow file {parent_dir}")
                                 else:
                                     modules = map(importlib.import_module,custom_py_files)
-                                    print(f"Custom modules imported {modules}")
+                                    logger.info(f"Custom modules imported {modules}")
                                 user_workflow = load_workflow(workflow_path.__str__())
                             except yaml.loader.ConstructorError as e:
-                                print("\033[91m While loading workflow, got the following error which may mean you need to install the corresponding module in your Python environment: \033[0m")
-                                print(e)
+                                logger.error("\033[91m While loading workflow, got the following error which may mean you need to install the corresponding module in your Python environment: \033[0m")
+                                logger.error(e)
                                 
                             #user_workflow = load_workflow(workflow_path)
-                            print("Workflow loaded from file")
+                            logger.info("Workflow loaded from file")
                         
                         assert type(user_workflow) is Workflow, "Workflow loading error. Check if file is workflow or if required libraries are installed"
                         
@@ -556,8 +563,8 @@ def _napari_lattice_widget_wrapper():
                         #print(input_arg_first, input_arg_last, first_task_name,last_task_name )
                         #get list of tasks
                         task_list = list(user_workflow._tasks.keys())
-                        print("Workflow loaded:")
-                        print(user_workflow)
+                        logger.info(f"Workflow loaded:{user_workflow}")
+                        #logger.info()
                         
                         #when using fields, self.time_preview.value 
                         assert time_preview < LLSZWidget.LlszMenu.lattice.time, "Time is out of range"
@@ -570,7 +577,7 @@ def _napari_lattice_widget_wrapper():
                         config.channel = channel
                         config.time = time
                         
-                        print("Processing for Time:", time,"and Channel: ", channel)
+                        logger.info(f"Processing for Time: {time} and Channel: {channel}")
                         
                         vol = LLSZWidget.LlszMenu.lattice.data
 
@@ -613,7 +620,7 @@ def _napari_lattice_widget_wrapper():
                                 #As the original image is scaled, the coordinates are in microns, so we need to convert
                                 #roi to from micron to canvas/world coordinates
                                 roi_choice = [x/LLSZWidget.LlszMenu.lattice.dy for x in roi_choice]
-                                print("Previewing ROI ", roi_idx)
+                                logger.info(f"Previewing ROI {roi_idx}")
                                 if LLSZWidget.LlszMenu.deconvolution.value:
                                     user_workflow.set("crop_deskew_image",crop_volume_deskew,
                                                                 original_volume = vol_zyx, 
@@ -739,8 +746,8 @@ def _napari_lattice_widget_wrapper():
                                 #set input to subsequent task as deconvolution output
                                 user_workflow.set(input_arg_first,"deconvolution")
 
-                        print("Workflow to be executed:")
-                        print(user_workflow)
+                        logger.info("Workflow to be executed:")
+                        logger.info(user_workflow)
                         #Execute workflow
                         processed_vol = user_workflow.get(task_name_last)
                         
@@ -1072,4 +1079,4 @@ def _napari_lattice_widget_wrapper():
     widget._widget._layout.setAlignment(Qt.AlignTop)
    
     #widget._widget._layout.setWidgetResizable(True)
-    return widget   
\ No newline at end of file
+    return widget   
