@@ -123,7 +123,7 @@ def save_img(vol,
     time_range = range(time_start, time_end+1)
     
     channel_range = range(channel_start, channel_end+1)
-    
+
     #Calculate new_pixel size in z after deskewing
     if angle>0:
         import math
@@ -165,9 +165,14 @@ def save_img(vol,
             lattice_class = lattice
             
     else:
-        decon_value = LLSZWidget.LlszMenu.deconvolution.value
-        lattice_class = LLSZWidget.LlszMenu.lattice
-        decon_option = LLSZWidget.LlszMenu.lattice.decon_processing
+        try:
+            decon_value = LLSZWidget.LlszMenu.deconvolution.value
+            lattice_class = LLSZWidget.LlszMenu.lattice
+            decon_option = LLSZWidget.LlszMenu.lattice.decon_processing
+        except:
+            decon_value = 0
+            lattice_class = 0
+            decon_option = 0
         
     
 
@@ -251,7 +256,7 @@ def save_img(vol,
                                    voxel_size_xyz=(dx, dy, new_dz),
                                    voxel_units='um')
                 
-                print("\nAppending volume to h5\n")
+                #print("\nAppending volume to h5\n")
             else:
                 images_array.append(processed_vol)
 
@@ -291,9 +296,9 @@ def save_img(vol,
                 im_final,
                 resolution=(1./dx, 1./dy,"MICROMETER"),    #specify resolution unit for consistent metadata)
                 metadata={'spacing': new_dz, 'unit': 'um', 'axes': 'TZCYX'},
-                imagej=True) 
+                imagej=True)
         im_final = None
-   
+
     return
 
 def save_img_workflow(vol,
@@ -423,7 +428,7 @@ def save_img_workflow(vol,
         #use data from first timepoint to get the output type from workflow
         #check if multiple objects in the workflow output, if so, get the index for each item
         #currently, images, lists and dictionaries are supported
-        if time_point == 0:
+        if loop_time_idx == 0:
             
             #get no of elements
             
@@ -477,7 +482,7 @@ def save_img_workflow(vol,
             for writer_idx, image_idx in enumerate(image_element_index):
                 #access the image
                 if len(channel_range)==1:
-                    im_final = np.stack(output_array[image_idx,...]).astype(raw_vol.dtype)
+                    im_final = np.stack(output_array[0,image_idx]).astype(raw_vol.dtype)
                 else:
                     im_final = np.stack(output_array[:,image_idx]).astype(raw_vol.dtype)
                 if save_file_type == 'h5':
@@ -572,8 +577,9 @@ class LatticeData():
         self.skew = skew
         
         #if image layer
+
         if type(img) is image.Image: #napari layer image
-            #check if its an aicsimageio object and has voxel size info            
+            #check if its an aicsimageio object and has voxel size info
             if 'aicsimage' in img.metadata.keys() and img.metadata['aicsimage'].physical_pixel_sizes != (None,None,None):
                 img_data_aics = img.metadata['aicsimage']
                 self.data = img_data_aics.dask_data
