@@ -9,10 +9,16 @@ import dask.array as da
 
 import pyclesperanto_prototype as cle
 from read_roi import read_roi_zip
+from read_roi import read_roi_file
 
 from napari_workflows import Workflow
 from tifffile import imsave
 
+#Enable Logging
+import logging
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
 #get bounding box of ROI in 3D and the shape of the ROI
 def calculate_crop_bbox(shape, z_start:int, z_end:int):
     """Get bounding box as vertices in 3D in the form xyz
@@ -158,9 +164,15 @@ def read_imagej_roi(roi_zip_path):
 
     Returns:
         list: List of ROIs
-    """    
-    assert  path.splitext(roi_zip_path)[1] == ".zip", "ImageJ ROI file needs to be a zip file"
-    ij_roi = read_roi_zip(roi_zip_path)
+    """
+    roi_extension = path.splitext(roi_zip_path)[1]
+    assert   roi_extension == ".roi" or roi_extension == ".zip", "ImageJ ROI file needs to be a zip/roi file"
+
+    if roi_extension == ".zip":
+        ij_roi = read_roi_zip(roi_zip_path)
+
+    if roi_extension == ".roi":
+        ij_roi = read_roi_file(roi_zip_path)
 
     #initialise list of rois
     roi_list = []
@@ -238,7 +250,7 @@ def modify_workflow_task(old_arg,task_key:str,new_arg,workflow):
     modified_task=tuple(task_list)
     return modified_task
 
-
+#TODO: CHANGE so user can select modules? Safer
 def get_all_py_files(directory): 
     """get all py files within directory and return as a list of filenames
     Args:
@@ -433,6 +445,7 @@ def check_dimensions(user_time_start:int,user_time_end,user_channel_start:int,us
     assert 0<=user_time_start<=max_time, f"Time start should be 0 or end time: {total_time-1}"
     assert 0<=user_channel_start<=max_channels, f"Channel start should be 0 or end channels: {total_channels-1}"
     
+
     #Not everyone will be aware that indexing starts at zero and ends at channel-1 or time -1
     #below only accounts for ending
     
@@ -441,17 +454,47 @@ def check_dimensions(user_time_start:int,user_time_end,user_channel_start:int,us
         print(f"Detected end time as {user_time_end}, but Python indexing starts at zero so last timepoint should be {total_time-1}")
         user_time_end = user_time_end-1
         print(f"Adjusting end time to {user_time_end}")
+    elif user_time_end == 0:
+        user_time_end = user_time_end+1
         
     #If user enters total time as last time, correct for indexing by subtracting it by 1
     if user_channel_end == total_channels:
         print(f"Detected end channel as {user_channel_end}, but Python indexing starts at zero so last channel should be {total_channels-1}")
         user_channel_end = user_channel_end-1
         print(f"Adjusting channel end to {user_channel_end}")
+    elif user_channel_end == 0:
+        user_channel_end = user_channel_end+1
+        
+    assert 0< user_time_end <= max_time, f"Time is out of range. End time: {max_time}"
+    assert 0< user_channel_end <= max_channels, f"Channel is out of range. End channels: {max_channels}"
     
-    assert 0<= user_time_end <= max_time, f"Time is out of range. End time: {max_time}"
-    assert 0<= user_channel_end <= max_channels, f"Channel is out of range. End channels: {max_channels}"
-    
-    print(f"Time start,end: {user_time_start,user_time_end}, Channel start,end: {user_channel_start,user_channel_end}")
+    #logging.debug(f"Time start,end: {user_time_start,user_time_end}, Channel start,end: {user_channel_start,user_channel_end}")
     
     return None
-                            
\ No newline at end of file
+
+#Reference: https://github.com/VolkerH/Lattice_Lightsheet_Deskew_Deconv/blob/master/examples/find_PSF_support.ipynb                            
+def crop_psf(psf_img:np.ndarray,threshold:float=3e-3):
+    """ Crop a PSF image based on the threshold specifiied
+
+    Args:
+        psf_img (np.ndarray): PSF image
+        threshold (float): Threshold value (0 to 1) as its a 32-bit image
+
+    Returns:
+        np.ndarray: Cropped PSF image
+    """    
+    #get max value
+    psf_max = psf_img.max()
+    psf_threshold = psf_max * threshold
+    #print(psf_threshold)
+    psf_filtered = psf_img>psf_threshold
+    #Get dimensions for min and max, where psf is greater than threshold
+    min_z,min_y,min_x = np.min(np.where(psf_filtered),axis = 1)
+    max_z,max_y,max_x = np.max(np.where(psf_filtered),axis = 1)
+    
+    #info for debugging
+    psf_shape = np.max(np.where(psf_filtered),axis = 1) - np.min(np.where(psf_filtered),axis = 1)
+    logging.debug(f"Shape of cropped psf is {psf_shape}")
+    
+    psf_crop = psf_img[min_z:max_z,min_y:max_y,min_x:max_x]
+    return psf_crop
\ No newline at end of file
